declare module "RequestPool.types" {
    export interface IRequestPoolInitialProps {
        limit?: number;
        type?: 'pop' | 'shift';
    }
    export interface IRequestPoolPushProps {
        tube?: string;
        action: () => Promise<any>;
    }
    export interface IRequestPoolRemoveProps {
        id: number;
        tube?: string;
    }
    export interface IRequestPoolJob {
        id: number;
        action: () => Promise<any>;
    }
    export interface IRequestPoolTube {
        index: number;
        jobs: IRequestPoolJob[];
        limit: number;
        counter: number;
        enabled: boolean;
        type: 'pop' | 'shift';
    }
    export interface IRequestPoolCreateTubeProps {
        name: string;
        limit?: number;
        type?: 'pop' | 'shift';
    }
    export interface IRequestPoolRemoveTubeProps {
        name: string;
    }
    export interface IRequestPoolEnableTubeProps {
        name: string;
    }
    export interface IRequestPoolDisableTubeProps {
        name: string;
    }
}
declare module "RequestPool" {
    import { IRequestPoolCreateTubeProps, IRequestPoolDisableTubeProps, IRequestPoolEnableTubeProps, IRequestPoolInitialProps, IRequestPoolJob, IRequestPoolPushProps, IRequestPoolRemoveProps, IRequestPoolRemoveTubeProps, IRequestPoolTube } from "RequestPool.types";
    export class ConcurrentRequestPool {
        private readonly limit;
        private readonly type;
        private counter;
        private tubes;
        constructor({ limit, type, }?: IRequestPoolInitialProps);
        get state(): {
            tubes: {
                [x: string]: IRequestPoolTube;
            };
            limit: number;
            type: 'pop' | 'shift';
            counter: number;
        };
        push: ({ tube, action, }: IRequestPoolPushProps) => number | false;
        remove: ({ tube, id, }: IRequestPoolRemoveProps) => boolean;
        createTube: ({ name, limit, type, }: IRequestPoolCreateTubeProps) => boolean;
        removeTube: ({ name, }: IRequestPoolRemoveTubeProps) => IRequestPoolJob[] | false;
        enableTube: ({ name }: IRequestPoolEnableTubeProps) => boolean;
        disableTube: ({ name, }: IRequestPoolDisableTubeProps) => boolean;
        private processTube;
        private processQueue;
    }
}
declare module "index" {
    export { ConcurrentRequestPool } from "RequestPool";
}
